﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Kresleni
{
    public partial class Window : Form
    {
        Pen pen;
        Brush brush;
        int cnt = 1;

        public Window()
        {
            InitializeComponent();
            pictureBox_SizeChanged (null, null);
            comboBox1.SelectedIndex = 1;

            Panel p2 = newPanel (Color.CornflowerBlue);
            Panel p3 = newPanel (Color.Lime);

            pen = new Pen (colorPanel.BackColor);
            brush = new SolidBrush (p2.BackColor);
        }

        private Panel newPanel (Color color)
        {
            Panel panel = new Panel ();
            panel.Parent = toolPanel;
            panel.BackColor = color;
            cnt ++;
            panel.Left = cnt * colorPanel.Left + (cnt-1) * colorPanel.Width;
            panel.Top = colorPanel.Top;
            panel.Width = colorPanel.Width;
            panel.Height = colorPanel.Height;
            panel.MouseDown += this.colorPanel_MouseDown;
            return panel;
        }

        private void colorPanel_MouseDown (object sender, MouseEventArgs e)
        {
            Panel panel = (Panel) sender;
            Color color = panel.BackColor;

            pen = new Pen (color);
        }

        private void pictureBox_SizeChanged(object sender, EventArgs e)
        {
            int w = pictureBox.Width;
            int h = pictureBox.Height;

            Bitmap old = null;
            if (pictureBox.Image != null)
            {
                old = new Bitmap (pictureBox.Image);
                if (pictureBox.Image.Width > w)  w = pictureBox.Image.Width;
                if (pictureBox.Image.Height > h) h = pictureBox.Image.Height;
            }

            pictureBox.Image = new Bitmap (w, h);
            Graphics g = Graphics.FromImage (pictureBox.Image);
            Brush b = new SolidBrush (Color.White);
            g.FillRectangle (b, 0, 0, w, h);

            if (old != null)
               g.DrawImage (old, 0, 0);
        }


        private int X0, Y0;
        private bool down = false;
        private Bitmap save = null;

        private void pictureBox_MouseDown(object sender, MouseEventArgs e)
        {
            X0 = e.X;
            Y0 = e.Y;
            down = true;
            save = new Bitmap (pictureBox.Image);
        }
        private void pictureBox_MouseMove(object sender, MouseEventArgs e)
        {
            if (down)
            {
                Graphics g = Graphics.FromImage (pictureBox.Image);
                g.DrawImage (save, 0, 0);
                Pen pen = new Pen (Color.Gray);
                int inx = comboBox1.SelectedIndex;

                // int X1 = Math.Min (X0, e.X);
                int X1 = X0;
                int Y1 = Y0;
                int X2 = e.X;
                int Y2 = e.Y;

                if (inx == 0)
                   g.DrawLine (pen, X1, Y1, X2, Y2);
                else if (inx == 1)
                {
                    if (X2 < X1) { int t = X2; X2 = X1; X1 = t; }
                    if (Y2 < Y1) { int t = Y2; Y2 = Y1; Y1 = t; }
                    g.DrawRectangle(pen, X1, Y1, X2 - X1, Y2 - Y1);
                }
                else if (inx == 2)
                    g.DrawEllipse(pen, X1, Y1, X2 - X1, Y2 - Y1);

                pictureBox.Invalidate();
            }
        }
        private void pictureBox_MouseUp(object sender, MouseEventArgs e)
        {
            if (down)
            {
                down = false;
                Graphics g = Graphics.FromImage(pictureBox.Image);
                g.DrawImage (save, 0, 0);
                int inx = comboBox1.SelectedIndex;

                int X1 = X0;
                int Y1 = Y0;
                int X2 = e.X;
                int Y2 = e.Y;

                if (inx == 0)
                    g.DrawLine (pen, X1, Y1, X2, Y2);
                else if (inx == 1)
                {
                    if (X2 < X1) { int t = X2; X2 = X1; X1 = t; }
                    if (Y2 < Y1) { int t = Y2; Y2 = Y1; Y1 = t; }
                    g.FillRectangle(brush, X1, Y1, X2 - X1, Y2 - Y1);
                    g.DrawRectangle (pen, X1, Y1, X2 - X1, Y2 - Y1);
                }
                else if (inx == 2)
                {
                    g.FillEllipse (brush, X1, Y1, X2 - X1, Y2 - Y1);
                    g.DrawEllipse (pen, X1, Y1, X2 - X1, Y2 - Y1);
                }

                pictureBox.Invalidate();
            }
        }

        private void quitMenu_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void pictureBox_Click(object sender, EventArgs e)
        {
        }

        private void openMenu_Click(object sender, EventArgs e)
        {
            if (openDialog.ShowDialog() == DialogResult.OK)
            {
                pictureBox.Image = new Bitmap (openDialog.FileName);
                pictureBox_SizeChanged (null, null);
            }

        }


    }
}
